@@ -10,16 +10,16 @@ declare_id!("mgrMbgLbusR19KEKMa9WsYDAeL94Tavgc9JHRB1CCGz");
 pub mod cardinal_token_manager {
     use super::*;
 
-    pub fn init(ctx: Context<InitCtx>, seed: Vec<u8>, bump: u8, num_invalidators: u8) -> ProgramResult {
-        init::handler(ctx, seed, bump, num_invalidators)
+    pub fn init(ctx: Context<InitCtx>, mint: Pubkey, bump: u8, num_invalidators: u8) -> ProgramResult {
+        init::handler(ctx, mint, bump, num_invalidators)
     }
 
     pub fn set_payment_manager(ctx: Context<SetPaymentManagerCtx>, payment_manager: Pubkey) -> ProgramResult {
         set_payment_manager::handler(ctx, payment_manager)
     }
 
-    pub fn set_claim_authority(ctx: Context<SetClaimAuthorityCtx>, claim_authority: Pubkey) -> ProgramResult {
-        set_claim_authority::handler(ctx, claim_authority)
+    pub fn set_claim_approver(ctx: Context<SetClaimApproverCtx>, claim_approver: Pubkey) -> ProgramResult {
+        set_claim_approver::handler(ctx, claim_approver)
     }
 
     pub fn set_transfer_authority(ctx: Context<SetTransferAuthorityCtx>, transfer_authority: Pubkey) -> ProgramResult {
