@@ -24,7 +24,7 @@ pub enum TokenManagerKind {
 }
 
 pub fn token_manager_size(num_invalidators: usize) -> usize {
-    return (8 + 1 + 32 + 32 + 8 + 1 + 1 + 32 + 32 + 32 + num_invalidators * 32) as usize
+    return (8 + 32 + 1 + 1 + 32 + 32 + 8 + 1 + 1 + 32 + 32 + 32 + 32 + num_invalidators * 32) + 8 as usize
 }
 
 pub const MAX_INVALIDATORS: u8 = 5;
@@ -40,7 +40,7 @@ pub struct TokenManager {
     pub state: u8,
     pub recipient_token_account: Pubkey,
     pub payment_manager: Option<Pubkey>,
-    pub claim_authority: Option<Pubkey>,
+    pub claim_approver: Option<Pubkey>,
     pub transfer_authority: Option<Pubkey>,
     pub invalidators: Vec<Pubkey>,
 }
